{ config, lib, pkgs, ... }:

{
  imports = [
    ./hardware-configuration.nix
    ./webapps/default.nix
  ];

  user = {
    packages = with pkgs; [
      git
      curl
    ];
  };

  users.groups.dotfiles = {};

  normalUsers = {
    reidlab = {
      conf = {
        packages = with pkgs; [ bat tree micro duf ];
        extraGroups = [ "wheel" "dotfiles" ];
      };

      homeConf.home = {
        sessionVariables = {
          EDITOR = "micro";
        };
      };
    };
  };

  keyboard = {
    locale = "en_US.UTF-8";
    variant = "qwerty";
  };

  modules = {
    services = {
      ssh = {
        enable = true;
        requirePassword = true;
      };

      postgres.enable = true;

      redis.enable = true;

      mosh.enable = true;
    };
  };

  time.timeZone = "America/Los_Angeles";

  networking = {
    hostName = "nixos-server-reid";
    wireless = {
      environmentFile = "/run/secrets/wireless.env";
      enable = true;
      userControlled.enable = true;
      networks.Ryan.psk = "@password@";
    };
  };

  boot.loader.grub.enable = false;
  boot.loader.generic-extlinux-compatible.enable = true;
}
